@@ -9,6 +9,7 @@
 #              ddrrun.py --facts=/path_to/facts --rules=/path_to/rules --flags=/path_to/flags --init=/path_to/initial-facts --tests=/path_to/test-facts --model=0 --runone=0
 
 import os
+import sys
 from ddrclass import DDR
 from optparse import OptionParser
 
@@ -52,8 +53,8 @@ def main():
     parser.add_option("--rules", dest="rules", type="string", default='ddr-rules',
                       help="Relative path to the file containing the RULES: default: ddr-rules")
     parser.add_option("--flags", dest="flags", type="string", default='ddr-flags',
-                      help="Relative path to the file containing control flags: default: ddr-flags")
-    parser.add_option("--devices", dest="devices", type="string", default='ddr-devices',
+                      help="Relative path to the file containing control flags: default: ddr-flags.yaml")
+    parser.add_option("--devices", dest="devices", type="string", default='ddr-devices.yaml',
                       help="Relative path to the file containing use case devices: default: ddr-devices")
     parser.add_option("--tests", dest="tests", type="string", default='ddr-tests',
                       help="Relative path to the file containing the test facts: default: ddr-tests")
@@ -65,10 +66,10 @@ def main():
                       help="Relative path to the file containing the simulated facts for rule execution file: default: ddr-sim")
     parser.add_option("--parsers", dest="parsers", type="string", default='ddrparsers.py',
                       help="Relative path to the file containing any special parsers required for the usecase: default: ddrparsers.py")
-    parser.add_option("--model", dest="model", type=int, default=0,
-                      help="Set to 1 to use ddr-control model")
     parser.add_option("--runone", dest="runone", type=int, default=0,
                       help="Set to 1 to stop  DDR  after one execution cycle")
+    parser.add_option("--results", dest="results", type=int, default=0,
+                      help="Set to 1 to print DDR data returned from DDR execution")
 
     (o, args) = parser.parse_args()
     factsfile = o.facts
@@ -80,8 +81,8 @@ def main():
     controlfile = o.control
     simfile = o.sim
     parserfile = o.parsers
-    model_control = o.model
     run_one = o.runone
+    results_print = o.results
     #
     # Run the main  DDR  script
     #
@@ -90,13 +91,20 @@ def main():
     #
     # Create instance of ddr class
     # 
-        engine = DDR()
+        ddr_instance = DDR()
     #
-    # Start DDR passing a the list of configuration files, whether to use model control and a single execution flag
+    # Start DDR passing a the list of configuration files and a single execution control flag
     #
-        engine.ddr(flist, model_control, run_one)
+        ddr_instance.ddr(flist, run_one)
+        print("**********  DDR Execution Complete ******************\n")
+        ddr_usecase_results = ddr_instance.get_notification()
+        if results_print == 1:
+            print("**********  DDR Usecase Results ******************\n")
+            print(ddr_usecase_results)
     except Exception as e:
-        print("%%%%% DDR Execution Terminated: " + str(e))
+        print("%%%% DDR Execution Terminated: " + str(e) + " DDR CLIPs environment initialization failed - verify device reachability")
+    return
 
 if __name__ == "__main__":
     main()
+    sys.exit(0)
\ No newline at end of file
